==> tumbler-0.0.1.tgz: package/bin/tumbler-server.js <==
#!/usr/bin/env node
(function() {
  var ARGUMENTS, ARGUMENTS_PARSER, DEFAULT_CONFIG, argument_parser, compare_path, erase, fs, http, main, merge_dic, mime, path, prepare_directory, prompt, request_handler, run_deploy, run_server, serve_static_file, spawn, tumbler, visit_directory, yesno_prompt;
  http = require('http');
  fs = require('fs');
  path = require('path');
  spawn = require('child_process').spawn;
  mime = require('mime');
  tumbler = require("tumbler");
  DEFAULT_CONFIG = {
    port: 10000,
    path: process.cwd()
  };
  ARGUMENTS = [[["-p", "--port"], "port", true, "Server port"], [["-d", "--directory"], "path", true, "Directory"], [["--deploy"], "deploy", true, "Deploy"], [["-h", "--help"], "help", false, "Print this help"]];
  serve_static_file = function(response, filepath) {
    var content_type, file, stat;
    try {
      if (path.existsSync(filepath)) {
        stat = fs.statSync(filepath);
        if (stat.isDirectory()) {
          response.writeHead(404);
          return response.end("That's a directory.");
        } else {
          content_type = mime.lookup(filepath);
          response.writeHead(200, {
            'content-type': content_type
          });
          file = fs.createReadStream(filepath);
          return file.pipe(response);
        }
      } else {
        response.writeHead(404);
        return response.end("File not found");
      }
    } catch (error) {
      response.writeHead(500);
      return response.end("Error " + error_msg);
    }
  };
  request_handler = function(builder, config) {
    return function(request, response) {
      var failure_callback, filepath, serve_file, url, url_base;
      response.setHeader("Access-Control-Allow-Origin", "*");
      url = request.url;
      console.log('GET ', url);
      url_base = url.split('?', 1);
      filepath = config.path + url_base;
      serve_file = function() {
        return serve_static_file(response, filepath);
      };
      failure_callback = function(err_msg) {
        response.writeHead(500);
        return response.end(err_msg);
      };
      return builder.build(filepath, serve_file, failure_callback);
    };
  };
  merge_dic = function(d, d2) {
    var k, v;
    for (k in d2) {
      v = d2[k];
      d[k] = v;
    }
    return d;
  };
  compare_path = function(left, right) {
    return fs.realpathSync(left) !== fs.realpathSync(right);
  };
  argument_parser = function(argument_options_, default_config) {
    var argument_config, argument_options, config_key, help, need_arg, option, options, parse_option_map, _i, _j, _len, _len2, _ref;
    argument_options = argument_options_.slice(0);
    argument_config = default_config;
    parse_option_map = {};
    for (_i = 0, _len = argument_options.length; _i < _len; _i++) {
      _ref = argument_options[_i], options = _ref[0], config_key = _ref[1], need_arg = _ref[2], help = _ref[3];
      for (_j = 0, _len2 = options.length; _j < _len2; _j++) {
        option = options[_j];
        parse_option_map[option] = [config_key, need_arg];
      }
    }
    return {
      help: function() {
        var _k, _len3, _ref2;
        console.log("\nusage:");
        console.log(' ' + __filename + " [options]\n");
        console.log('options :');
        for (_k = 0, _len3 = argument_options.length; _k < _len3; _k++) {
          _ref2 = argument_options[_k], options = _ref2[0], config_key = _ref2[1], need_arg = _ref2[2], help = _ref2[3];
          if (need_arg) {
            console.log('   ' + options + ' option : ' + help);
          } else {
            console.log('   ' + options + ' : ' + help);
          }
        }
        return console.log('');
      },
      parse: function(argv) {
        var config, parse_options;
        config = merge_dic({}, DEFAULT_CONFIG);
        while (argv.length > 0) {
          option = argv.shift();
          parse_options = parse_option_map[option];
          if (parse_options != null) {
            config_key = parse_options[0], need_arg = parse_options[1];
            if (need_arg) {
              config[config_key] = argv.shift();
            } else {
              config[config_key] = true;
            }
          } else {
            throw "Option unknown : " + option;
          }
        }
        return config;
      }
    };
  };
  ARGUMENTS_PARSER = argument_parser(ARGUMENTS);
  prompt = function(question, callback) {
    console.log(question);
    process.stdin.resume();
    return process.stdin.on("data", function(data) {
      process.stdin.pause();
      return callback(data.toString().trim());
    });
  };
  visit_directory = function(dir_path, action, cond) {
    var child, child_fullpath, child_stat, children, _i, _len, _results;
    if ((cond != null) && cond(dir_path)) {
      console.log("ok", dir_path);
      children = fs.readdirSync(dir_path);
      _results = [];
      for (_i = 0, _len = children.length; _i < _len; _i++) {
        child = children[_i];
        _results.push((function() {
          if (!(/\..*/.test(child))) {
            child_fullpath = path.join(dir_path, child);
            child_stat = fs.statSync(child_fullpath);
            if (child_stat.isDirectory()) {
              visit_directory(child_fullpath, action);
            }
            try {
              return action(child_fullpath);
            } catch (msg) {
              throw "Failed on " + child_fullpath;
            }
          }
        })());
      }
      return _results;
    } else {
      return console.log("fail", dir_path);
    }
  };
  erase = function(filepath) {
    var file_stat;
    file_stat = fs.statSync(filepath);
    if (file_stat.isDirectory()) {
      return fs.rmdirSync(filepath);
    } else {
      return fs.unlinkSync(filepath);
    }
  };
  yesno_prompt = function(question, callback) {
    var handle_answer;
    handle_answer = function(answer) {
      var is_yes, _ref;
      is_yes = ((_ref = answer.toLowerCase()) === "y" || _ref === "yes");
      return callback(is_yes);
    };
    return prompt(question + " [y/n]", handle_answer);
  };
  prepare_directory = function(directory_path, callback) {
    var content;
    if (path.existsSync(directory_path)) {
      content = fs.readdirSync(directory_path);
      if (content.length === 0) {
        return callback(directory_path);
      } else {
        console.log("Directory not empty");
        console.log(directory_path);
        return yesno_prompt("Do you want to erase all of its content", function(answer) {
          if (answer) {
            console.log("cleaning up");
            return visit_directory(directory_path, erase);
          } else {
            throw "Aborting...";
          }
        });
      }
    } else {
      try {
        fs.mkdirSync(directory_path, 0777);
      } catch (e) {
        throw "Could not make directory : " + directory_path;
      }
      return callback(directory_path);
    }
  };
  run_deploy = function(config) {
    return console.log("deploy not implemented yet.");
  };
  run_server = function(builder, config) {
    var server;
    server = http.createServer(request_handler(builder, config));
    console.log('Listening on port : ' + config.port);
    return server.listen(config.port);
  };
  main = function() {
    var builder, config;
    builder = new tumbler.Builder();
    builder.register_compiler(new tumbler.BundleCompiler());
    builder.register_compiler(new tumbler.SimpleCompiler('coffee', 'js', 'coffee', ['-p']));
    builder.register_compiler(new tumbler.SimpleCompiler('less', 'css', 'lessc', []));
    builder.register_compiler(new tumbler.TrivialCompiler());
    try {
      config = ARGUMENTS_PARSER.parse(process.argv.slice(2, (process.argv.length + 1) || 9e9));
      console.log(config);
      if (config.help) {
        return ARGUMENTS_PARSER.help();
      } else if (config.deploy) {
        return run_deploy(config);
      } else {
        console.log("Run server");
        return run_server(builder, config);
      }
    } catch (e) {
      console.log(e);
      return ARGUMENTS_PARSER.help();
    }
  };
  if (require.main === module) {
    main();
  }
}).call(this);

==> tumbler-0.0.2.tgz: package/bin/tumbler-server.js <==
#!/usr/bin/env node
(function() {
  var ARGUMENTS, ARGUMENTS_PARSER, DEFAULT_CONFIG, argument_parser, compare_path, erase, fs, http, main, merge_dic, mime, path, prepare_directory, prompt, request_handler, run_deploy, run_server, serve_static_file, spawn, tumbler, visit_directory, yesno_prompt;
  http = require('http');
  fs = require('fs');
  path = require('path');
  spawn = require('child_process').spawn;
  mime = require('mime');
  tumbler = require("tumbler");
  DEFAULT_CONFIG = {
    port: 10000,
    path: process.cwd()
  };
  ARGUMENTS = [[["-p", "--port"], "port", true, "Server port"], [["-d", "--directory"], "path", true, "Directory"], [["--deploy"], "deploy", true, "Deploy"], [["-h", "--help"], "help", false, "Print this help"]];
  serve_static_file = function(response, filepath) {
    var content_type, file, stat;
    try {
      if (path.existsSync(filepath)) {
        stat = fs.statSync(filepath);
        if (stat.isDirectory()) {
          response.writeHead(404);
          return response.end("That's a directory.");
        } else {
          content_type = mime.lookup(filepath);
          response.writeHead(200, {
            'content-type': content_type
          });
          file = fs.createReadStream(filepath);
          return file.pipe(response);
        }
      } else {
        response.writeHead(404);
        return response.end("File not found");
      }
    } catch (error) {
      response.writeHead(500);
      return response.end("Error " + error_msg);
    }
  };
  request_handler = function(builder, config) {
    return function(request, response) {
      var failure_callback, filepath, serve_file, url, url_base;
      response.setHeader("Access-Control-Allow-Origin", "*");
      url = request.url;
      console.log('GET ', url);
      url_base = url.split('?', 1);
      filepath = config.path + url_base;
      serve_file = function() {
        return serve_static_file(response, filepath);
      };
      failure_callback = function(err_msg) {
        response.writeHead(500);
        return response.end(err_msg);
      };
      return builder.build(filepath, serve_file, failure_callback);
    };
  };
  merge_dic = function(d, d2) {
    var k, v;
    for (k in d2) {
      v = d2[k];
      d[k] = v;
    }
    return d;
  };
  compare_path = function(left, right) {
    return fs.realpathSync(left) !== fs.realpathSync(right);
  };
  argument_parser = function(argument_options_, default_config) {
    var argument_config, argument_options, config_key, help, need_arg, option, options, parse_option_map, _i, _j, _len, _len2, _ref;
    argument_options = argument_options_.slice(0);
    argument_config = default_config;
    parse_option_map = {};
    for (_i = 0, _len = argument_options.length; _i < _len; _i++) {
      _ref = argument_options[_i], options = _ref[0], config_key = _ref[1], need_arg = _ref[2], help = _ref[3];
      for (_j = 0, _len2 = options.length; _j < _len2; _j++) {
        option = options[_j];
        parse_option_map[option] = [config_key, need_arg];
      }
    }
    return {
      help: function() {
        var _k, _len3, _ref2;
        console.log("\nusage:");
        console.log(' ' + __filename + " [options]\n");
        console.log('options :');
        for (_k = 0, _len3 = argument_options.length; _k < _len3; _k++) {
          _ref2 = argument_options[_k], options = _ref2[0], config_key = _ref2[1], need_arg = _ref2[2], help = _ref2[3];
          if (need_arg) {
            console.log('   ' + options + ' option : ' + help);
          } else {
            console.log('   ' + options + ' : ' + help);
          }
        }
        return console.log('');
      },
      parse: function(argv) {
        var config, parse_options;
        config = merge_dic({}, DEFAULT_CONFIG);
        while (argv.length > 0) {
          option = argv.shift();
          parse_options = parse_option_map[option];
          if (parse_options != null) {
            config_key = parse_options[0], need_arg = parse_options[1];
            if (need_arg) {
              config[config_key] = argv.shift();
            } else {
              config[config_key] = true;
            }
          } else {
            throw "Option unknown : " + option;
          }
        }
        return config;
      }
    };
  };
  ARGUMENTS_PARSER = argument_parser(ARGUMENTS);
  prompt = function(question, callback) {
    console.log(question);
    process.stdin.resume();
    return process.stdin.on("data", function(data) {
      process.stdin.pause();
      return callback(data.toString().trim());
    });
  };
  visit_directory = function(dir_path, action, cond) {
    var child, child_fullpath, child_stat, children, _i, _len, _results;
    if ((cond != null) && cond(dir_path)) {
      console.log("ok", dir_path);
      children = fs.readdirSync(dir_path);
      _results = [];
      for (_i = 0, _len = children.length; _i < _len; _i++) {
        child = children[_i];
        _results.push((function() {
          if (!(/\..*/.test(child))) {
            child_fullpath = path.join(dir_path, child);
            child_stat = fs.statSync(child_fullpath);
            if (child_stat.isDirectory()) {
              visit_directory(child_fullpath, action);
            }
            try {
              return action(child_fullpath);
            } catch (msg) {
              throw "Failed on " + child_fullpath;
            }
          }
        })());
      }
      return _results;
    } else {
      return console.log("fail", dir_path);
    }
  };
  erase = function(filepath) {
    var file_stat;
    file_stat = fs.statSync(filepath);
    if (file_stat.isDirectory()) {
      return fs.rmdirSync(filepath);
    } else {
      return fs.unlinkSync(filepath);
    }
  };
  yesno_prompt = function(question, callback) {
    var handle_answer;
    handle_answer = function(answer) {
      var is_yes, _ref;
      is_yes = ((_ref = answer.toLowerCase()) === "y" || _ref === "yes");
      return callback(is_yes);
    };
    return prompt(question + " [y/n]", handle_answer);
  };
  prepare_directory = function(directory_path, callback) {
    var content;
    if (path.existsSync(directory_path)) {
      content = fs.readdirSync(directory_path);
      if (content.length === 0) {
        return callback(directory_path);
      } else {
        console.log("Directory not empty");
        console.log(directory_path);
        return yesno_prompt("Do you want to erase all of its content", function(answer) {
          if (answer) {
            console.log("cleaning up");
            return visit_directory(directory_path, erase);
          } else {
            throw "Aborting...";
          }
        });
      }
    } else {
      try {
        fs.mkdirSync(directory_path, 0777);
      } catch (e) {
        throw "Could not make directory : " + directory_path;
      }
      return callback(directory_path);
    }
  };
  run_deploy = function(config) {
    return console.log("deploy not implemented yet.");
  };
  run_server = function(builder, config) {
    var server;
    server = http.createServer(request_handler(builder, config));
    console.log('Listening on port : ' + config.port);
    return server.listen(config.port);
  };
  main = function() {
    var builder, config, sprite;
    builder = new tumbler.Builder();
    builder.register_compiler(new tumbler.BundleCompiler());
    builder.register_compiler(new tumbler.SimpleCompiler('coffee', 'js', 'coffee', ['-p']));
    try {
      sprite = require('tumbler-sprite');
      builder.register_compiler(new sprite.SpriteCompiler());
    } catch (exception) {
      console.log("Couldn't load sprite");
    }
    builder.register_compiler(new tumbler.SimpleCompiler('less', 'css', 'lessc', []));
    builder.register_compiler(new tumbler.TrivialCompiler());
    try {
      config = ARGUMENTS_PARSER.parse(process.argv.slice(2, (process.argv.length + 1) || 9e9));
      console.log(config);
      if (config.help) {
        return ARGUMENTS_PARSER.help();
      } else if (config.deploy) {
        return run_deploy(config);
      } else {
        console.log("Run server");
        return run_server(builder, config);
      }
    } catch (e) {
      console.log(e);
      return ARGUMENTS_PARSER.help();
    }
  };
  if (require.main === module) {
    main();
  }
}).call(this);
